@@ -1,4 +1,4 @@
-/*	$Id: Class0.h,v 1.3 2006/10/31 22:00:28 faxguy Exp $ */
+/*	$Id$ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -37,8 +37,8 @@ public:
 
     bool setupModem(bool isSend = true);
     virtual bool setupFlowControl(FlowControl fc);
-    CallStatus	dial(const char* number, const char* origin, fxStr& emsg);
-    CallStatus dialResponse(fxStr& emsg);
+    CallStatus	dial(const char* number, Status& eresult);
+    CallStatus dialResponse(Status& eresult);
 
     bool isFaxModem() const;			// XXX safe to cast
 };
