@@ -83,7 +83,7 @@ private:
     u_char*	recvRow;	// current receive row raster
     u_char*	recvPageStart;	// pointer to start of page buffer
     u_long*	savedWriteOff;	// file offset at start of page data
-    u_long*	savedStripByteCounts;	// byte counts at start of page data
+    tiff_bytecount_t*	savedStripByteCounts;	// byte counts at start of page data
     int		decodedPixels;	// number of pixels decoded with error
     int		decoderFd[2];	// file descriptors for the decoder pipe
     int		counterFd[2];	// file descriptors for the counter pipe
