@@ -1,4 +1,4 @@
-/*	$Id: faxGettyApp.h 960 2009-12-04 05:10:46Z faxguy $ */
+/*	$Id$ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -81,10 +81,8 @@ private:
     AnswerType	answerRotary[3];	// rotary selection of answer types
     fxStr	faxRcvdCmd;		// fax received command
     fxStr	dynamicConfig;		// command to dynamically alter configuration
-    fxStr	tsiRecvdCmd;		// command to check TSI
     u_int	modemPriority;		// modem priority passed to faxq
     bool	logCalls;		// Log all calls for FaxAcctInfo
-    bool	logRecv;		// Log received faxes to xferfaxlog
     bool	rejectCall;
 
     static faxGettyApp* _instance;
@@ -108,24 +106,23 @@ private:
     bool	setupModem(bool isSend);
     void	discardModem(bool dropDTR);
 // inbound call handling
-    bool	processCall(CallType ctype, FaxMachineInfo info, fxStr& emsg, CallID& callid);
+    bool	processCall(CallType ctype, Status& eresult, const CallID& callid);
     CallType	runGetty(const char* what,
 		    Getty* (*newgetty)(const fxStr&, const fxStr&),
-		    const char* args, fxStr &emsg, int& status,
+		    const char* args, Status &eresult,
                     bool keepLock, const CallID& callid, 
 		    bool keepModem = false);
     void	setRingsBeforeAnswer(int rings);
     void	listenBegin();
     void	listenForRing();
     void	answerPhoneCmd(AnswerType, const char* dialnumber = NULL);
-    void	answerPhone(AnswerType, CallType, CallID& callid, const char* dialnumber = NULL);
+    void	answerPhone(AnswerType, CallType, const CallID& callid, const char* dialnumber = NULL);
     void	answerCleanup();
-    bool	answerCall(AnswerType atype, CallType& ctype, FaxMachineInfo info, fxStr& emsg, CallID& callid, const char* dialnumber = NULL);
+    bool	answerCall(AnswerType atype, CallType& ctype, Status& eresult, const CallID& callid, const char* dialnumber = NULL);
 
     friend void AnswerTimeoutHandler::timerExpired(long, long);
 // miscellaneous stuff
     bool	sendModemStatus(const char* msg);
-    void	scriptedConfig(fxStr& cmd, fxStr& emsg);
 // FIFO-related stuff
     void	openFIFOs();
     void	closeFIFOs();
@@ -139,7 +136,6 @@ private:
     void	notifyPageRecvd(TIFF* tif, FaxRecvInfo&, int ppm);
     void	notifyDocumentRecvd(FaxRecvInfo&);
     void	notifyRecvDone(FaxRecvInfo&);
-    bool	processTSIRecvdCmd(FaxRecvInfo&, fxStr&);
 public:
     faxGettyApp(const fxStr& device, const fxStr& devID);
     ~faxGettyApp();
